import { __decorate, __metadata } from 'tslib';
import { Directive, forwardRef, ElementRef, Input, NgModule } from '@angular/core';
import { NG_VALIDATORS, FormsModule } from '@angular/forms';
import { findParent, add, remove, InputBoolean, InputNumber } from 'ngx-weui/core';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * Generated from: input.directive.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * 文本框，指令是对文本框格式校验（邮箱、手机、身份证等）、视觉效果的增强而已
 */
var InputDirective = /** @class */ (function () {
    function InputDirective(el) {
        this.el = el;
        /**
         * 是否必填项，**等同于** <intpu required> 的值，当值必填时会有视觉效果
         */
        this.required = 'warn';
        /**
         * 是否自动清除内容中的空格
         */
        this.cleaner = false;
    }
    /**
     * @return {?}
     */
    InputDirective.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
        this.parentEl = findParent(this.el.nativeElement, '.weui-cell');
        if (!this.parentEl) {
            console.error('父DOM结构至少必须包含一个.weui-cell');
            return;
        }
        // 检查是否有 weui-cell__ft
        this.ftEl = add(this.parentEl);
    };
    /**
     * @return {?}
     */
    InputDirective.prototype.ngOnChanges = /**
     * @return {?}
     */
    function () {
        this._createValidator();
        if (this._onChange)
            this._onChange();
    };
    /**
     * @private
     * @return {?}
     */
    InputDirective.prototype._createValidator = /**
     * @private
     * @return {?}
     */
    function () {
        var _this = this;
        /** @type {?} */
        var regex = null;
        if (this.inputRegex) {
            if (typeof this.inputRegex === 'string') {
                regex = new RegExp("^" + this.inputRegex + "$");
            }
            else {
                regex = this.inputRegex;
            }
        }
        else {
            // 默认行为
            if (this.inputType) {
                switch (this.inputType) {
                    case 'qq':
                    case 'number':
                        regex = /^[0-9]+$/;
                        break;
                    case 'digit':
                        regex = /^[.0-9]+$/;
                        break;
                    case 'tel':
                        regex = /^[-.0-9]+$/;
                        break;
                    case 'email':
                        regex = /^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
                        this.cleaner = true;
                        break;
                    case 'mobile':
                        regex = /^1[0-9]{10}$/;
                        this.cleaner = true;
                        break;
                    case 'idcard': // 身份证
                        regex = /^[X0-9]{15,18}$/;
                        this.cleaner = true;
                        break;
                }
            }
        }
        this._validator = (/**
         * @param {?} control
         * @return {?}
         */
        function (control) {
            /** @type {?} */
            var value = control.value;
            if (value == null || value.length === 0) {
                if (_this.required !== undefined)
                    return { icon: _this.required, type: 'required', actualValue: value };
                return null;
            }
            if (_this.cleaner && value.includes(' ')) {
                value = value.replace(/ /g, '');
                control.setValue(value, { emitEvent: false });
            }
            return regex === null || regex.test(value) ? null : { icon: 'warn', type: 'regex', actualValue: value };
        });
    };
    /**
     * @param {?} fn
     * @return {?}
     */
    InputDirective.prototype.registerOnValidatorChange = /**
     * @param {?} fn
     * @return {?}
     */
    function (fn) {
        this._onChange = fn;
    };
    /**
     * @param {?} c
     * @return {?}
     */
    InputDirective.prototype.validate = /**
     * @param {?} c
     * @return {?}
     */
    function (c) {
        if (!this.parentEl)
            return null;
        /** @type {?} */
        var ret = this._validator(c);
        if (ret === null) {
            this.parentEl.classList.remove('weui-cell_warn');
            remove(this.ftEl, 'i');
        }
        else {
            remove(this.ftEl, 'i');
            this.parentEl.classList.add('weui-cell_warn');
            /** @type {?} */
            var icon = "weui-icon-" + ret.icon;
            add(this.ftEl, '.' + icon, 'i', icon);
        }
        return ret;
    };
    InputDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[weui-input]',
                    exportAs: 'weuiInput',
                    providers: [
                        {
                            provide: NG_VALIDATORS,
                            useExisting: forwardRef((/**
                             * @return {?}
                             */
                            function () { return InputDirective; })),
                            multi: true,
                        },
                    ],
                },] }
    ];
    /** @nocollapse */
    InputDirective.ctorParameters = function () { return [
        { type: ElementRef }
    ]; };
    InputDirective.propDecorators = {
        inputType: [{ type: Input, args: ['weui-input',] }],
        inputRegex: [{ type: Input, args: ['weui-regex',] }],
        required: [{ type: Input, args: ['weui-required',] }],
        cleaner: [{ type: Input, args: ['weui-cleaner',] }]
    };
    __decorate([
        InputBoolean(),
        __metadata("design:type", Boolean)
    ], InputDirective.prototype, "cleaner", void 0);
    return InputDirective;
}());
if (false) {
    /**
     * @type {?}
     * @private
     */
    InputDirective.prototype.parentEl;
    /**
     * @type {?}
     * @private
     */
    InputDirective.prototype.ftEl;
    /**
     * @type {?}
     * @private
     */
    InputDirective.prototype._validator;
    /**
     * @type {?}
     * @private
     */
    InputDirective.prototype._onChange;
    /**
     * 文本框类型，**不等同于** <intpu type="text"> 的值
     * 因为 weui-input 属性只是内置格式校验的简洁写法而已。
     * 内置包括：number/digit(允许小数点)/qq/email/tel/mobile/idcard，如需要更为复杂的校验可以使用 weui-regex
     * @type {?}
     */
    InputDirective.prototype.inputType;
    /**
     * 格式校验正则表达式，优先级高于 [weui-input]。
     * @type {?}
     */
    InputDirective.prototype.inputRegex;
    /**
     * 是否必填项，**等同于** <intpu required> 的值，当值必填时会有视觉效果
     * @type {?}
     */
    InputDirective.prototype.required;
    /**
     * 是否自动清除内容中的空格
     * @type {?}
     */
    InputDirective.prototype.cleaner;
    /**
     * @type {?}
     * @private
     */
    InputDirective.prototype.el;
}

/**
 * @fileoverview added by tsickle
 * Generated from: check.directive.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var ChecklistDirective = /** @class */ (function () {
    function ChecklistDirective() {
        this.checked = false;
    }
    Object.defineProperty(ChecklistDirective.prototype, "value", {
        set: /**
         * @param {?} val
         * @return {?}
         */
        function (val) {
            this._value = val;
            this.checked = this.targetArray.indexOf(val) !== -1;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @param {?} $event
     * @return {?}
     */
    ChecklistDirective.prototype._change = /**
     * @param {?} $event
     * @return {?}
     */
    function ($event) {
        if ($event.target.checked) {
            this.targetArray.push(this._value);
        }
        else {
            this.targetArray.splice(this.targetArray.indexOf(this._value), 1);
        }
    };
    ChecklistDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[weui-checklist]',
                    exportAs: 'weuiChecklist',
                    host: {
                        '(change)': '_change($event)',
                        '[checked]': 'checked',
                    },
                },] }
    ];
    ChecklistDirective.propDecorators = {
        targetArray: [{ type: Input, args: ['weui-checklist',] }],
        value: [{ type: Input, args: ['weui-value',] }]
    };
    return ChecklistDirective;
}());
if (false) {
    /** @type {?} */
    ChecklistDirective.prototype.targetArray;
    /** @type {?} */
    ChecklistDirective.prototype.checked;
    /**
     * @type {?}
     * @private
     */
    ChecklistDirective.prototype._value;
}

/**
 * @fileoverview added by tsickle
 * Generated from: vcode.directive.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * 获取验证码
 */
var VCodeDirective = /** @class */ (function () {
    function VCodeDirective(el) {
        this.el = el;
        /**
         * 时长（单位：秒），默认：`60`
         */
        this.seconds = 60;
        /**
         * 倒计时模板，使用 `${num}` 表示当前秒数
         */
        // tslint:disable-next-line: no-invalid-template-strings
        this.tpl = '${num} 秒';
        /**
         * 重新发送提醒文本
         */
        this.error = '重新发送';
        this._disabled = false;
    }
    /**
     * @return {?}
     */
    VCodeDirective.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
        if (typeof this.onSend !== 'function')
            console.error('weui-vcode必须传递一个返回值为 `Observable<boolean>` 函数');
        this._cur = this.el.nativeElement.innerHTML;
    };
    /**
     * @return {?}
     */
    VCodeDirective.prototype._onClick = /**
     * @return {?}
     */
    function () {
        var _this = this;
        this._disabled = true;
        this.onSend().subscribe((/**
         * @param {?} res
         * @return {?}
         */
        function (res) {
            res ? _this.tick() : _this.err();
        }));
    };
    /**
     * @private
     * @return {?}
     */
    VCodeDirective.prototype.err = /**
     * @private
     * @return {?}
     */
    function () {
        this._disabled = false;
        this.el.nativeElement.innerHTML = this.error;
    };
    /**
     * @private
     * @return {?}
     */
    VCodeDirective.prototype.tick = /**
     * @private
     * @return {?}
     */
    function () {
        var _this = this;
        /** @type {?} */
        var count = this.seconds < 1 ? 1 : this.seconds;
        this.setText(count);
        this._t = setInterval((/**
         * @return {?}
         */
        function () {
            if (--count <= 0) {
                _this._disabled = false;
                _this.el.nativeElement.innerHTML = _this._cur;
                _this.destroy();
            }
            else
                _this.setText(count);
        }), 1000);
    };
    /**
     * @private
     * @param {?} num
     * @return {?}
     */
    VCodeDirective.prototype.setText = /**
     * @private
     * @param {?} num
     * @return {?}
     */
    function (num) {
        this.el.nativeElement.innerHTML = this.tpl.replace(/\${num}/, num.toString());
    };
    /**
     * @private
     * @return {?}
     */
    VCodeDirective.prototype.destroy = /**
     * @private
     * @return {?}
     */
    function () {
        if (this._t) {
            clearInterval(this._t);
            this._t = null;
        }
    };
    /**
     * @return {?}
     */
    VCodeDirective.prototype.ngOnDestroy = /**
     * @return {?}
     */
    function () {
        this.destroy();
    };
    VCodeDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[weui-vcode]',
                    exportAs: 'weuiVcode',
                    host: {
                        '(click)': '_onClick()',
                        '[disabled]': '_disabled',
                    },
                },] }
    ];
    /** @nocollapse */
    VCodeDirective.ctorParameters = function () { return [
        { type: ElementRef }
    ]; };
    VCodeDirective.propDecorators = {
        onSend: [{ type: Input, args: ['weui-vcode',] }],
        seconds: [{ type: Input, args: ['weui-seconds',] }],
        tpl: [{ type: Input, args: ['weui-tpl',] }],
        error: [{ type: Input, args: ['weui-error',] }]
    };
    __decorate([
        InputNumber(),
        __metadata("design:type", Number)
    ], VCodeDirective.prototype, "seconds", void 0);
    return VCodeDirective;
}());
if (false) {
    /**
     * 发送事件
     * @type {?}
     */
    VCodeDirective.prototype.onSend;
    /**
     * 时长（单位：秒），默认：`60`
     * @type {?}
     */
    VCodeDirective.prototype.seconds;
    /**
     * 倒计时模板，使用 `${num}` 表示当前秒数
     * @type {?}
     */
    VCodeDirective.prototype.tpl;
    /**
     * 重新发送提醒文本
     * @type {?}
     */
    VCodeDirective.prototype.error;
    /** @type {?} */
    VCodeDirective.prototype._disabled;
    /**
     * @type {?}
     * @private
     */
    VCodeDirective.prototype._cur;
    /**
     * @type {?}
     * @private
     */
    VCodeDirective.prototype._t;
    /**
     * @type {?}
     * @private
     */
    VCodeDirective.prototype.el;
}

/**
 * @fileoverview added by tsickle
 * Generated from: textarea.directive.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * 文本域字数统计
 */
var TextareaDirective = /** @class */ (function () {
    function TextareaDirective(el) {
        this.el = el;
        this.fillStr = '';
        this._cn = 1;
        /**
         * 最大长度，0表示不受限
         */
        this.maxlength = 0;
    }
    Object.defineProperty(TextareaDirective.prototype, "cn", {
        /**
         * 中文部分应该算多少个字符，使用 `/[^\x00-\xff]/g` 正则表达式统计中文部分（默认：1个字符）
         */
        set: /**
         * 中文部分应该算多少个字符，使用 `/[^\x00-\xff]/g` 正则表达式统计中文部分（默认：1个字符）
         * @param {?} value
         * @return {?}
         */
        function (value) {
            this._cn = value;
            this.fillStr = new Array(+value).fill('*').join('');
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    TextareaDirective.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
        this.init();
    };
    /**
     * @param {?} changes
     * @return {?}
     */
    TextareaDirective.prototype.ngOnChanges = /**
     * @param {?} changes
     * @return {?}
     */
    function (changes) {
        if (changes.maxlength) {
            this.init()._onChange(this._value);
        }
    };
    /**
     * @private
     * @template THIS
     * @this {THIS}
     * @return {THIS}
     */
    TextareaDirective.prototype.init = /**
     * @private
     * @template THIS
     * @this {THIS}
     * @return {THIS}
     */
    function () {
        /** @type {?} */
        var clsName = "weui-textarea-counter";
        /** @type {?} */
        var pel = (/** @type {?} */ (this)).el.nativeElement.parentElement;
        (/** @type {?} */ (this)).maxlength = +(/** @type {?} */ (this)).maxlength;
        if ((/** @type {?} */ (this)).maxlength <= 0) {
            remove(pel, '.' + clsName);
            (/** @type {?} */ (this))._count = null;
        }
        else {
            (/** @type {?} */ (this))._count = add(pel, '.' + clsName, 'div', clsName);
        }
        return (/** @type {?} */ (this));
    };
    /**
     * @param {?} value
     * @return {?}
     */
    TextareaDirective.prototype._onChange = /**
     * @param {?} value
     * @return {?}
     */
    function (value) {
        if (!this._count)
            return;
        value = value || '';
        if (this._cn > 1) {
            value = value.replace(/[^\x00-\xff]/g, this.fillStr);
        }
        this._value = value;
        this._count.innerHTML = value.length + " / " + this.maxlength;
    };
    TextareaDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[weui-textarea]',
                    exportAs: 'weuiTextarea',
                    host: {
                        '(input)': '_onChange($event.target?.value)',
                    },
                },] }
    ];
    /** @nocollapse */
    TextareaDirective.ctorParameters = function () { return [
        { type: ElementRef }
    ]; };
    TextareaDirective.propDecorators = {
        maxlength: [{ type: Input }],
        cn: [{ type: Input, args: ['weui-cn',] }]
    };
    __decorate([
        InputNumber(),
        __metadata("design:type", Number)
    ], TextareaDirective.prototype, "maxlength", void 0);
    return TextareaDirective;
}());
if (false) {
    /**
     * @type {?}
     * @private
     */
    TextareaDirective.prototype.fillStr;
    /**
     * @type {?}
     * @private
     */
    TextareaDirective.prototype._cn;
    /**
     * 最大长度，0表示不受限
     * @type {?}
     */
    TextareaDirective.prototype.maxlength;
    /**
     * @type {?}
     * @private
     */
    TextareaDirective.prototype._value;
    /**
     * @type {?}
     * @private
     */
    TextareaDirective.prototype._count;
    /**
     * @type {?}
     * @private
     */
    TextareaDirective.prototype.el;
}

/**
 * @fileoverview added by tsickle
 * Generated from: form.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var COMPONENTS = [InputDirective, VCodeDirective, TextareaDirective, ChecklistDirective];
var FormModule = /** @class */ (function () {
    function FormModule() {
    }
    FormModule.decorators = [
        { type: NgModule, args: [{
                    imports: [CommonModule, FormsModule],
                    declarations: COMPONENTS,
                    exports: COMPONENTS,
                },] }
    ];
    return FormModule;
}());

/**
 * @fileoverview added by tsickle
 * Generated from: public-api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: ngx-weui-form.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { ChecklistDirective, FormModule, InputDirective, TextareaDirective, VCodeDirective };
//# sourceMappingURL=ngx-weui-form.js.map
