import { __decorate, __metadata } from 'tslib';
import { Injectable, ɵɵdefineInjectable, EventEmitter, Component, ChangeDetectionStrategy, ViewEncapsulation, Input, Output, ViewChild, NgModule } from '@angular/core';
import { InputNumber } from 'ngx-weui/core';
import { Subject } from 'rxjs';
import { debounceTime, distinctUntilChanged } from 'rxjs/operators';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';

/**
 * @fileoverview added by tsickle
 * Generated from: searchbar.config.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var SearchBarConfig = /** @class */ (function () {
    function SearchBarConfig() {
        /**
         * 占位符，默认：`搜索`
         */
        this.placeholder = '搜索';
        /**
         * 取消按键文字，默认：`取消`
         */
        this.cancelText = '取消';
        /**
         * 去抖时长（单位：ms），默认：`300`
         */
        this.debounceTime = 300;
    }
    SearchBarConfig.decorators = [
        { type: Injectable, args: [{ providedIn: 'root' },] }
    ];
    /** @nocollapse */ SearchBarConfig.ɵprov = ɵɵdefineInjectable({ factory: function SearchBarConfig_Factory() { return new SearchBarConfig(); }, token: SearchBarConfig, providedIn: "root" });
    return SearchBarConfig;
}());
if (false) {
    /**
     * 占位符，默认：`搜索`
     * @type {?}
     */
    SearchBarConfig.prototype.placeholder;
    /**
     * 取消按键文字，默认：`取消`
     * @type {?}
     */
    SearchBarConfig.prototype.cancelText;
    /**
     * 去抖时长（单位：ms），默认：`300`
     * @type {?}
     */
    SearchBarConfig.prototype.debounceTime;
}

/**
 * @fileoverview added by tsickle
 * Generated from: searchbar.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var SearchBarComponent = /** @class */ (function () {
    function SearchBarComponent(DEF) {
        this._q = '';
        /**
         * 搜索回调
         */
        this.search = new EventEmitter();
        /**
         * 取消回调
         */
        this.cancel = new EventEmitter();
        /**
         * 清空回调
         */
        this.clear = new EventEmitter();
        /**
         * 提交回调（指的是键盘回车后）
         */
        this.submit = new EventEmitter();
        this._focus = false;
        this._subject = new Subject();
        Object.assign(this, DEF);
    }
    Object.defineProperty(SearchBarComponent.prototype, "value", {
        set: /**
         * @param {?} _value
         * @return {?}
         */
        function (_value) {
            this._q = _value;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    SearchBarComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
        var _this = this;
        this._sub = this._subject.pipe(debounceTime(this.debounceTime), distinctUntilChanged()).subscribe((/**
         * @param {?} q
         * @return {?}
         */
        function (q) {
            _this.search.emit(q);
        }));
    };
    /**
     * @return {?}
     */
    SearchBarComponent.prototype._doFocus = /**
     * @return {?}
     */
    function () {
        this._term.nativeElement.focus();
    };
    /**
     * @return {?}
     */
    SearchBarComponent.prototype._onBlur = /**
     * @return {?}
     */
    function () {
        if (this._q === '')
            this._focus = false;
    };
    /**
     * @return {?}
     */
    SearchBarComponent.prototype._onSearch = /**
     * @return {?}
     */
    function () {
        this._subject.next(this._q);
    };
    /**
     * @return {?}
     */
    SearchBarComponent.prototype._onCancel = /**
     * @return {?}
     */
    function () {
        this._q = '';
        this._onBlur();
        this._subject.next('');
        this.cancel.emit();
    };
    /**
     * @return {?}
     */
    SearchBarComponent.prototype._onClear = /**
     * @return {?}
     */
    function () {
        this._q = '';
        this._doFocus();
        this._subject.next('');
        this.clear.emit();
    };
    /**
     * @param {?} e
     * @return {?}
     */
    SearchBarComponent.prototype._onSubmit = /**
     * @param {?} e
     * @return {?}
     */
    function (e) {
        e.preventDefault();
        e.stopPropagation();
        this._subject.next(this._q);
        this.submit.emit(this._q);
        return false;
    };
    /**
     * @return {?}
     */
    SearchBarComponent.prototype.ngOnDestroy = /**
     * @return {?}
     */
    function () {
        if (this._sub)
            this._sub.unsubscribe();
    };
    SearchBarComponent.decorators = [
        { type: Component, args: [{
                    selector: 'weui-searchbar',
                    exportAs: 'weuiSearchbar',
                    template: "<form class=\"weui-search-bar__form\" (ngSubmit)=\"_onSubmit($event)\">\n  <div class=\"weui-search-bar__box\">\n    <i class=\"weui-icon-search\"></i>\n    <input\n      #term\n      type=\"search\"\n      autocomplete=\"off\"\n      name=\"q\"\n      class=\"weui-search-bar__input\"\n      [placeholder]=\"placeholder\"\n      [(ngModel)]=\"_q\"\n      (ngModelChange)=\"_onSearch()\"\n      (focus)=\"_focus = true\"\n      (blur)=\"_onBlur()\"\n    />\n    <a href=\"javascript:\" class=\"weui-icon-clear\" (click)=\"_onClear()\"></a>\n  </div>\n  <label class=\"weui-search-bar__label\" (click)=\"_doFocus()\">\n    <i class=\"weui-icon-search\"></i>\n    <span>{{ placeholder }}</span>\n  </label>\n</form>\n<a class=\"weui-search-bar__cancel-btn\" (click)=\"_onCancel()\">{{ cancelText }}</a>\n",
                    host: {
                        '[class.weui-search-bar]': "true",
                        '[class.weui-search-bar_focusing]': "_focus",
                    },
                    preserveWhitespaces: false,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    encapsulation: ViewEncapsulation.None
                }] }
    ];
    /** @nocollapse */
    SearchBarComponent.ctorParameters = function () { return [
        { type: SearchBarConfig }
    ]; };
    SearchBarComponent.propDecorators = {
        value: [{ type: Input }],
        placeholder: [{ type: Input }],
        cancelText: [{ type: Input }],
        debounceTime: [{ type: Input }],
        search: [{ type: Output }],
        cancel: [{ type: Output }],
        clear: [{ type: Output }],
        submit: [{ type: Output }],
        _term: [{ type: ViewChild, args: ['term', { static: true },] }]
    };
    __decorate([
        InputNumber(),
        __metadata("design:type", Number)
    ], SearchBarComponent.prototype, "debounceTime", void 0);
    return SearchBarComponent;
}());
if (false) {
    /** @type {?} */
    SearchBarComponent.prototype._q;
    /**
     * 占位符，默认：`搜索`
     * @type {?}
     */
    SearchBarComponent.prototype.placeholder;
    /**
     * 取消按键文字，默认：`取消`
     * @type {?}
     */
    SearchBarComponent.prototype.cancelText;
    /**
     * 去抖时长（单位：ms），默认：`300`
     * @type {?}
     */
    SearchBarComponent.prototype.debounceTime;
    /**
     * 搜索回调
     * @type {?}
     */
    SearchBarComponent.prototype.search;
    /**
     * 取消回调
     * @type {?}
     */
    SearchBarComponent.prototype.cancel;
    /**
     * 清空回调
     * @type {?}
     */
    SearchBarComponent.prototype.clear;
    /**
     * 提交回调（指的是键盘回车后）
     * @type {?}
     */
    SearchBarComponent.prototype.submit;
    /** @type {?} */
    SearchBarComponent.prototype._focus;
    /**
     * @type {?}
     * @private
     */
    SearchBarComponent.prototype._term;
    /**
     * @type {?}
     * @private
     */
    SearchBarComponent.prototype._sub;
    /**
     * @type {?}
     * @private
     */
    SearchBarComponent.prototype._subject;
}

/**
 * @fileoverview added by tsickle
 * Generated from: searchbar.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var SearchBarModule = /** @class */ (function () {
    function SearchBarModule() {
    }
    SearchBarModule.decorators = [
        { type: NgModule, args: [{
                    imports: [CommonModule, FormsModule],
                    declarations: [SearchBarComponent],
                    exports: [SearchBarComponent],
                },] }
    ];
    return SearchBarModule;
}());

/**
 * @fileoverview added by tsickle
 * Generated from: public-api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: ngx-weui-searchbar.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { SearchBarComponent, SearchBarConfig, SearchBarModule };
//# sourceMappingURL=ngx-weui-searchbar.js.map
