import { __decorate, __metadata } from 'tslib';
import { EventEmitter, Component, forwardRef, ChangeDetectionStrategy, ViewEncapsulation, ElementRef, ChangeDetectorRef, Input, Output, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { InputNumber, InputBoolean } from 'ngx-weui/core';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * Generated from: slider.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var SliderComponent = /** @class */ (function () {
    function SliderComponent(el, cdr) {
        this.cdr = cdr;
        this.state = null;
        this.isInit = false;
        this.value = 0;
        /**
         * 允许的最小值，默认：`0`
         */
        this.min = 0;
        /**
         * 允许的最大值，默认：`100`
         */
        this.max = 100;
        /**
         * 步长，默认：`1`
         */
        this.step = 1;
        /**
         * 是否可用
         */
        this.enabled = true;
        this.showValue = true;
        /**
         * 值改变时触发
         */
        // tslint:disable-next-line: no-output-rename
        this.change = new EventEmitter();
        this.el = el.nativeElement;
    }
    /**
     * @return {?}
     */
    SliderComponent.prototype.ngAfterViewInit = /**
     * @return {?}
     */
    function () {
        this.isInit = true;
        this.trackEl = (/** @type {?} */ ((/** @type {?} */ (this.el.querySelector('.weui-slider__track')))));
        this.handlerEl = (/** @type {?} */ ((/** @type {?} */ (this.el.querySelector('.weui-slider__handler')))));
        this.onTouchStart = this.startHandle.bind(this);
        this.onTouchMove = this.moveHandle.bind(this);
        this.handlerEl.addEventListener('touchstart', this.onTouchStart, false);
        this.handlerEl.addEventListener('touchmove', this.onTouchMove, false);
    };
    /**
     * @return {?}
     */
    SliderComponent.prototype.ngOnDestroy = /**
     * @return {?}
     */
    function () {
        this.handlerEl.removeEventListener('touchstart', this.onTouchStart, false);
        this.handlerEl.removeEventListener('touchmove', this.onTouchMove, false);
    };
    /**
     * @private
     * @return {?}
     */
    SliderComponent.prototype.refresh = /**
     * @private
     * @return {?}
     */
    function () {
        this.state = {
            enabled: this.enabled,
            left: this.el.getBoundingClientRect().left,
            size: (/** @type {?} */ (((/** @type {?} */ ((/** @type {?} */ (this.el.querySelector('.weui-slider__inner')))))).offsetWidth)),
            percentage: [0, 0, 0],
            x: 0,
        };
        this.max = +this.max;
        this.min = +this.min;
        this.step = +this.step;
        this.setValue(this.value);
        this.layout();
    };
    /**
     * @private
     * @param {?} value
     * @return {?}
     */
    SliderComponent.prototype.setValue = /**
     * @private
     * @param {?} value
     * @return {?}
     */
    function (value) {
        if (this.max > this.min) {
            this.state.percentage = [
                // tslint:disable-next-line: binary-expression-operand-order
                (100 * (value - this.min)) / (this.max - this.min),
                0,
                (this.step * 100) / (this.max - this.min),
            ];
        }
        else {
            this.state.percentage = [0, 0, 100];
        }
    };
    /**
     * @private
     * @return {?}
     */
    SliderComponent.prototype.layout = /**
     * @private
     * @return {?}
     */
    function () {
        this.trackEl.style.width = this.state.percentage[0] + '%';
        this.handlerEl.style.left = this.state.percentage[0] + '%';
    };
    /**
     * @private
     * @param {?} $event
     * @return {?}
     */
    SliderComponent.prototype.startHandle = /**
     * @private
     * @param {?} $event
     * @return {?}
     */
    function ($event) {
        if (this.state === null)
            this.refresh();
        this.state.x = ($event.touches[0] || $event.changedTouches[0]).pageX;
    };
    /**
     * @private
     * @param {?} $event
     * @return {?}
     */
    SliderComponent.prototype.moveHandle = /**
     * @private
     * @param {?} $event
     * @return {?}
     */
    function ($event) {
        if (!this.state.enabled) {
            return;
        }
        /** @type {?} */
        var pageX = ($event.touches[0] || $event.changedTouches[0]).pageX;
        /** @type {?} */
        var xDiff = pageX - this.state.x;
        if (xDiff >= 15 || xDiff <= 15) {
            this.state.percentage[0] = this.getPercentage(pageX);
            this.layout();
            this.calculateValue(this.state.percentage[0]);
        }
    };
    /**
     * @private
     * @param {?} pageX
     * @return {?}
     */
    SliderComponent.prototype.getPercentage = /**
     * @private
     * @param {?} pageX
     * @return {?}
     */
    function (pageX) {
        /** @type {?} */
        var distanceToSlide = pageX - this.state.left;
        /** @type {?} */
        var percentage = (distanceToSlide / this.state.size) * 100;
        percentage = Math.round(percentage / this.state.percentage[2]) * this.state.percentage[2];
        return Math.max(0, Math.min(100, percentage));
    };
    /**
     * @private
     * @param {?} percentage
     * @return {?}
     */
    SliderComponent.prototype.calculateValue = /**
     * @private
     * @param {?} percentage
     * @return {?}
     */
    function (percentage) {
        /** @type {?} */
        var rawValue = (percentage / 100) * (this.max - this.min);
        // adjustment = this.min
        /** @type {?} */
        var value = this.min + Math.round(rawValue / this.step) * this.step;
        if (value < this.min)
            value = this.min;
        else if (value > this.max)
            value = this.max;
        this.value = value;
        this.onChange(this.value);
        this.onTouched();
        this.change.emit(this.value);
    };
    /**
     * @return {?}
     */
    SliderComponent.prototype.ngOnChanges = /**
     * @return {?}
     */
    function () {
        if (this.isInit)
            this.refresh();
    };
    /**
     * @param {?} value
     * @return {?}
     */
    SliderComponent.prototype.writeValue = /**
     * @param {?} value
     * @return {?}
     */
    function (value) {
        if (value) {
            this.value = +value;
            this.refresh();
            this.calculateValue(this.state.percentage[0]);
        }
        this.cdr.detectChanges();
    };
    /**
     * @param {?} fn
     * @return {?}
     */
    SliderComponent.prototype.registerOnChange = /**
     * @param {?} fn
     * @return {?}
     */
    function (fn) {
        this.onChange = fn;
    };
    /**
     * @param {?} fn
     * @return {?}
     */
    SliderComponent.prototype.registerOnTouched = /**
     * @param {?} fn
     * @return {?}
     */
    function (fn) {
        this.onTouched = fn;
    };
    /**
     * @param {?} isDisabled
     * @return {?}
     */
    SliderComponent.prototype.setDisabledState = /**
     * @param {?} isDisabled
     * @return {?}
     */
    function (isDisabled) {
        this.enabled = !isDisabled;
    };
    SliderComponent.decorators = [
        { type: Component, args: [{
                    selector: 'weui-slider, [weui-slider]',
                    exportAs: 'weuiSlider',
                    template: "<div *ngIf=\"!showValue\" class=\"weui-slider__inner\">\n  <div class=\"weui-slider__track\"></div>\n  <div class=\"weui-slider__handler\"></div>\n</div>\n<ng-container *ngIf=\"showValue\">\n  <div class=\"weui-slider\">\n    <div class=\"weui-slider__inner\">\n      <div class=\"weui-slider__track\"></div>\n      <div class=\"weui-slider__handler\"></div>\n    </div>\n  </div>\n  <div class=\"weui-slider-box__value\">{{ value }}</div>\n</ng-container>\n",
                    host: {
                        '[class.weui-slider-box]': 'showValue',
                        '[class.weui-slider]': '!showValue',
                        '[class.weui-slider__disabled]': '!enabled',
                    },
                    providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef((/**
                             * @return {?}
                             */
                            function () { return SliderComponent; })),
                            multi: true,
                        },
                    ],
                    preserveWhitespaces: false,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    encapsulation: ViewEncapsulation.None
                }] }
    ];
    /** @nocollapse */
    SliderComponent.ctorParameters = function () { return [
        { type: ElementRef },
        { type: ChangeDetectorRef }
    ]; };
    SliderComponent.propDecorators = {
        min: [{ type: Input, args: ['weui-min',] }],
        max: [{ type: Input, args: ['weui-max',] }],
        step: [{ type: Input, args: ['weui-step',] }],
        enabled: [{ type: Input, args: ['weui-enabled',] }],
        showValue: [{ type: Input, args: ['weui-show-value',] }],
        change: [{ type: Output, args: ['weui-change',] }]
    };
    __decorate([
        InputNumber(),
        __metadata("design:type", Number)
    ], SliderComponent.prototype, "min", void 0);
    __decorate([
        InputNumber(),
        __metadata("design:type", Number)
    ], SliderComponent.prototype, "max", void 0);
    __decorate([
        InputNumber(),
        __metadata("design:type", Number)
    ], SliderComponent.prototype, "step", void 0);
    __decorate([
        InputBoolean(),
        __metadata("design:type", Boolean)
    ], SliderComponent.prototype, "enabled", void 0);
    __decorate([
        InputBoolean(),
        __metadata("design:type", Boolean)
    ], SliderComponent.prototype, "showValue", void 0);
    return SliderComponent;
}());
if (false) {
    /**
     * @type {?}
     * @private
     */
    SliderComponent.prototype.el;
    /**
     * @type {?}
     * @private
     */
    SliderComponent.prototype.state;
    /**
     * @type {?}
     * @private
     */
    SliderComponent.prototype.isInit;
    /**
     * @type {?}
     * @private
     */
    SliderComponent.prototype.trackEl;
    /**
     * @type {?}
     * @private
     */
    SliderComponent.prototype.handlerEl;
    /**
     * @type {?}
     * @private
     */
    SliderComponent.prototype.onChange;
    /**
     * @type {?}
     * @private
     */
    SliderComponent.prototype.onTouched;
    /**
     * @type {?}
     * @private
     */
    SliderComponent.prototype.onTouchStart;
    /**
     * @type {?}
     * @private
     */
    SliderComponent.prototype.onTouchMove;
    /** @type {?} */
    SliderComponent.prototype.value;
    /**
     * 允许的最小值，默认：`0`
     * @type {?}
     */
    SliderComponent.prototype.min;
    /**
     * 允许的最大值，默认：`100`
     * @type {?}
     */
    SliderComponent.prototype.max;
    /**
     * 步长，默认：`1`
     * @type {?}
     */
    SliderComponent.prototype.step;
    /**
     * 是否可用
     * @type {?}
     */
    SliderComponent.prototype.enabled;
    /** @type {?} */
    SliderComponent.prototype.showValue;
    /**
     * 值改变时触发
     * @type {?}
     */
    SliderComponent.prototype.change;
    /**
     * @type {?}
     * @private
     */
    SliderComponent.prototype.cdr;
}

/**
 * @fileoverview added by tsickle
 * Generated from: slider.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var SliderModule = /** @class */ (function () {
    function SliderModule() {
    }
    SliderModule.decorators = [
        { type: NgModule, args: [{
                    imports: [CommonModule],
                    declarations: [SliderComponent],
                    exports: [SliderComponent],
                },] }
    ];
    return SliderModule;
}());

/**
 * @fileoverview added by tsickle
 * Generated from: public-api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: ngx-weui-slider.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { SliderComponent as SliderDirective, SliderModule };
//# sourceMappingURL=ngx-weui-slider.js.map
