import { __decorate, __metadata, __extends } from 'tslib';
import { Component, ChangeDetectorRef, EventEmitter, Directive, Input, Output, forwardRef, ChangeDetectionStrategy, ViewEncapsulation, NgModule } from '@angular/core';
import { InputBoolean } from 'ngx-weui/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';

/**
 * @fileoverview added by tsickle
 * Generated from: bar.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var BarComponent = /** @class */ (function () {
    function BarComponent(cdr) {
        this.cdr = cdr;
        this.tabs = [];
    }
    /**
     * @param {?} tab
     * @return {?}
     */
    BarComponent.prototype.add = /**
     * @param {?} tab
     * @return {?}
     */
    function (tab) {
        this.tabs.push(tab);
        tab.active = this.tabs.length === 1 && tab.active !== false;
    };
    /**
     * @param {?} tab
     * @return {?}
     */
    BarComponent.prototype.remove = /**
     * @param {?} tab
     * @return {?}
     */
    function (tab) {
        /** @type {?} */
        var index = this.tabs.indexOf(tab);
        if (index === -1 || this.isDestroyed) {
            return;
        }
        // Select a new tab if the tab to be removed is selected and not destroyed
        if (tab.active && this.hasAvailableTabs(index)) {
            /** @type {?} */
            var newActiveIndex = this.getClosestTabIndex(index);
            this.tabs[newActiveIndex].active = true;
        }
        tab.removed.emit(tab);
        this.tabs.splice(index, 1);
    };
    /**
     * @param {?} tab
     * @return {?}
     */
    BarComponent.prototype.setActive = /**
     * @param {?} tab
     * @return {?}
     */
    function (tab) {
        tab.active = true;
        tab.select.emit(tab);
    };
    /**
     * @return {?}
     */
    BarComponent.prototype.detectChanges = /**
     * @return {?}
     */
    function () {
        this.cdr.detectChanges();
    };
    /**
     * @protected
     * @param {?} index
     * @return {?}
     */
    BarComponent.prototype.getClosestTabIndex = /**
     * @protected
     * @param {?} index
     * @return {?}
     */
    function (index) {
        /** @type {?} */
        var tabsLength = this.tabs.length;
        if (!tabsLength) {
            return -1;
        }
        for (var step = 1; step <= tabsLength; step += 1) {
            /** @type {?} */
            var prevIndex = index - step;
            /** @type {?} */
            var nextIndex = index + step;
            if (this.tabs[prevIndex] && !this.tabs[prevIndex].disabled) {
                return prevIndex;
            }
            if (this.tabs[nextIndex] && !this.tabs[nextIndex].disabled) {
                return nextIndex;
            }
        }
        return -1;
    };
    /**
     * @protected
     * @param {?} index
     * @return {?}
     */
    BarComponent.prototype.hasAvailableTabs = /**
     * @protected
     * @param {?} index
     * @return {?}
     */
    function (index) {
        /** @type {?} */
        var tabsLength = this.tabs.length;
        if (!tabsLength) {
            return false;
        }
        for (var i = 0; i < tabsLength; i += 1) {
            if (!this.tabs[i].disabled && i !== index) {
                return true;
            }
        }
        return false;
    };
    /**
     * @return {?}
     */
    BarComponent.prototype.ngOnDestroy = /**
     * @return {?}
     */
    function () {
        this.isDestroyed = true;
    };
    BarComponent.decorators = [
        { type: Component, args: [{
                    selector: 'weui-bar-component',
                    template: ""
                }] }
    ];
    /** @nocollapse */
    BarComponent.ctorParameters = function () { return [
        { type: ChangeDetectorRef }
    ]; };
    return BarComponent;
}());
if (false) {
    /** @type {?} */
    BarComponent.prototype.tabs;
    /**
     * @type {?}
     * @protected
     */
    BarComponent.prototype.isDestroyed;
    /**
     * @type {?}
     * @private
     */
    BarComponent.prototype.cdr;
}

/**
 * @fileoverview added by tsickle
 * Generated from: tab.directive.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var TabDirective = /** @class */ (function () {
    function TabDirective(tab) {
        /**
         * 当tab激活时触发
         */
        this.select = new EventEmitter();
        /**
         * 当tab无效时触发
         */
        this.deselect = new EventEmitter();
        /**
         * 当tab移除时触发
         */
        this.removed = new EventEmitter();
        this._tabComp = tab;
        this._tabComp.add(this);
    }
    Object.defineProperty(TabDirective.prototype, "active", {
        /**
         * 激活
         */
        get: /**
         * 激活
         * @return {?}
         */
        function () {
            return this._active;
        },
        set: /**
         * @param {?} active
         * @return {?}
         */
        function (active) {
            var _this = this;
            if ((this.disabled && active) || !active) {
                if (!active) {
                    this._active = active;
                }
                this.deselect.emit(this);
                return;
            }
            this._active = active;
            this._tabComp.tabs.filter((/**
             * @param {?} t
             * @return {?}
             */
            function (t) { return t !== _this; })).forEach((/**
             * @param {?} tab
             * @return {?}
             */
            function (tab) { return (tab.active = false); }));
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    TabDirective.prototype.ngOnChanges = /**
     * @return {?}
     */
    function () {
        if (!this.activeIcon) {
            this.activeIcon = this.icon;
        }
        this._tabComp.detectChanges();
    };
    /**
     * @return {?}
     */
    TabDirective.prototype.ngOnDestroy = /**
     * @return {?}
     */
    function () {
        this._tabComp.remove(this);
    };
    TabDirective.decorators = [
        { type: Directive, args: [{
                    selector: 'weui-tab, [weui-tab]',
                    exportAs: 'weuiTab',
                    host: {
                        '[class.active]': 'active',
                    },
                },] }
    ];
    /** @nocollapse */
    TabDirective.ctorParameters = function () { return [
        { type: BarComponent }
    ]; };
    TabDirective.propDecorators = {
        heading: [{ type: Input }],
        disabled: [{ type: Input }],
        icon: [{ type: Input }],
        activeIcon: [{ type: Input }],
        badge: [{ type: Input }],
        select: [{ type: Output }],
        deselect: [{ type: Output }],
        removed: [{ type: Output }],
        active: [{ type: Input }]
    };
    __decorate([
        InputBoolean(),
        __metadata("design:type", Boolean)
    ], TabDirective.prototype, "disabled", void 0);
    __decorate([
        InputBoolean(),
        __metadata("design:type", Boolean),
        __metadata("design:paramtypes", [Boolean])
    ], TabDirective.prototype, "active", null);
    return TabDirective;
}());
if (false) {
    /**
     * 选项卡名称
     * @type {?}
     */
    TabDirective.prototype.heading;
    /**
     * 是否禁用
     * @type {?}
     */
    TabDirective.prototype.disabled;
    /**
     * icon图标，支持HTML
     * @type {?}
     */
    TabDirective.prototype.icon;
    /**
     * 激活时icon图标，支持HTML
     * @type {?}
     */
    TabDirective.prototype.activeIcon;
    /**
     * 徽章内容，支持数字或圆点
     * @type {?}
     */
    TabDirective.prototype.badge;
    /**
     * 当tab激活时触发
     * @type {?}
     */
    TabDirective.prototype.select;
    /**
     * 当tab无效时触发
     * @type {?}
     */
    TabDirective.prototype.deselect;
    /**
     * 当tab移除时触发
     * @type {?}
     */
    TabDirective.prototype.removed;
    /**
     * @type {?}
     * @protected
     */
    TabDirective.prototype._active;
    /**
     * @type {?}
     * @protected
     */
    TabDirective.prototype._tabComp;
}

/**
 * @fileoverview added by tsickle
 * Generated from: navbar.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * 顶部选项卡
 */
var NavbarComponent = /** @class */ (function (_super) {
    __extends(NavbarComponent, _super);
    function NavbarComponent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NavbarComponent.decorators = [
        { type: Component, args: [{
                    selector: 'weui-navbar',
                    exportAs: 'weuiNavbar',
                    template: "<div class=\"weui-navbar\">\n  <div\n    class=\"weui-navbar__item\"\n    [ngClass]=\"{ 'weui-bar__item_on': item.active }\"\n    [class.disabled]=\"item.disabled\"\n    *ngFor=\"let item of tabs\"\n    (click)=\"setActive(item)\"\n  >\n    {{ item.heading }}\n  </div>\n</div>\n<div class=\"weui-tab__panel\"><ng-content></ng-content></div>\n",
                    providers: [{ provide: BarComponent, useExisting: forwardRef((/**
                             * @return {?}
                             */
                            function () { return NavbarComponent; })) }],
                    host: {
                        '[class.weui-tab]': 'true',
                    },
                    preserveWhitespaces: false,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    encapsulation: ViewEncapsulation.None
                }] }
    ];
    return NavbarComponent;
}(BarComponent));

/**
 * @fileoverview added by tsickle
 * Generated from: tabbar.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * 底部选项卡
 */
var TabbarComponent = /** @class */ (function (_super) {
    __extends(TabbarComponent, _super);
    function TabbarComponent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TabbarComponent.decorators = [
        { type: Component, args: [{
                    selector: 'weui-tabbar',
                    exportAs: 'weuiTabbar',
                    template: "<div class=\"weui-tab__panel\"><ng-content></ng-content></div>\n<div class=\"weui-tabbar\">\n  <div\n    class=\"weui-tabbar__item\"\n    [ngClass]=\"{ 'weui-bar__item_on': item.active }\"\n    *ngFor=\"let item of tabs\"\n    (click)=\"setActive(item)\"\n  >\n    <div style=\"display: inline-block;position: relative;\">\n      <div class=\"weui-tabbar__icon\" [innerHTML]=\"item.active ? item.activeIcon : item.icon\"></div>\n      <span\n        class=\"weui-badge\"\n        style=\"position: absolute;top: -2px;right: -13px;\"\n        *ngIf=\"item.badge && item.badge !== 'dot'\"\n        >{{ item.badge }}</span\n      >\n      <span\n        class=\"weui-badge weui-badge_dot\"\n        style=\"position: absolute;top: 0;right: -6px;\"\n        *ngIf=\"item.badge && item.badge === 'dot'\"\n      ></span>\n    </div>\n    <p class=\"weui-tabbar__label\">{{ item.heading }}</p>\n  </div>\n</div>\n",
                    providers: [{ provide: BarComponent, useExisting: forwardRef((/**
                             * @return {?}
                             */
                            function () { return TabbarComponent; })) }],
                    host: {
                        '[class.weui-tab]': 'true',
                    },
                    preserveWhitespaces: false,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    encapsulation: ViewEncapsulation.None
                }] }
    ];
    return TabbarComponent;
}(BarComponent));

/**
 * @fileoverview added by tsickle
 * Generated from: tab.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var COMPONENTS = [TabDirective, NavbarComponent, TabbarComponent, BarComponent];
var TabModule = /** @class */ (function () {
    function TabModule() {
    }
    TabModule.decorators = [
        { type: NgModule, args: [{
                    imports: [CommonModule, FormsModule],
                    declarations: COMPONENTS,
                    exports: COMPONENTS,
                },] }
    ];
    return TabModule;
}());

/**
 * @fileoverview added by tsickle
 * Generated from: public-api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: ngx-weui-tab.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { BarComponent, NavbarComponent, TabDirective, TabModule, TabbarComponent };
//# sourceMappingURL=ngx-weui-tab.js.map
